@@ -128,6 +128,7 @@ class light_curve(observation):
         self._exposure_ = other._exposure_
 
         self._timedel_ = other._timedel_
+        self._timezero_ = other._timezero_
 
         self._tstart_ = other._tstart_
         self._tstop_ = other._tstop_
@@ -224,7 +225,7 @@ class light_curve(observation):
                     continue
 
                 if not (_x[i] >= GTI_START[curr_gti_ind] and _x[i] <= GTI_STOP[curr_gti_ind]):
-                    logger.info("Event # %d time %g not in gti bin %d %g -- %g " % (
+                    logger.debug("Event # %d time %g not in gti bin %d %g -- %g " % (
                     i, _x[i], curr_gti_ind, GTI_START[curr_gti_ind],
                     GTI_STOP[curr_gti_ind]))
 
@@ -254,11 +255,11 @@ class light_curve(observation):
                         logger.debug("GTI Threshold exceeded Stop accumulation\n")
                         gti_flag = 1
 
-                        # Increases GTI index
-                        curr_gti_ind += 1
-                        if (curr_gti_ind >= n_gti):
-                            end_flag = 1
-                            curr_gti_ind = n_gti - 1
+                    # Increases GTI index
+                    curr_gti_ind += 1
+                    if (curr_gti_ind >= n_gti):
+                        end_flag = 1
+                        curr_gti_ind = n_gti - 1
             else:
                 # In case no GTI is present
                 delta_t = 0
@@ -298,12 +299,12 @@ class light_curve(observation):
                     if (not end_flag):
 
                         if (n_gti > 0):
-                            logger.info(
-                                "\nDisregard points in GTI bin interval #" + str(curr_gti_ind - 1) + " = [s]  " + str(
+                            logger.debug(
+                                "Disregard points in GTI bin interval #" + str(curr_gti_ind - 1) + " = [s]  " + str(
                                     100 * local_t / (
                                             GTI_STOP[curr_gti_ind - 1] - GTI_START[curr_gti_ind - 1])))
                         elif local_t > 0:
-                            logger.info("\nDisregard " + str(local_t) + " s for long gap at " + str(_x[i]))
+                            logger.debug("Disregard " + str(local_t) + " s for long gap at " + str(_x[i]))
 
                         tot_disregard_time += local_t
                         if (local_t < 0):
@@ -432,9 +433,9 @@ class light_curve(observation):
                 # cout << j  << " GF= " << _dx[j] << " " << local_t << endl
 
                 if not end_flag:
-                    logger.info("Disregard points in interval " + str(curr_gti_ind - 1) + " = [s]  " +
+                    logger.debug("gti_flag, disregard points in interval " + str(curr_gti_ind - 1) + " = [s]  " +
                                 str(100 * local_t / (GTI_STOP[curr_gti_ind - 1] - GTI_START[
-                                    curr_gti_ind - 1])) + " \% (GTI FLAG)")
+                                    curr_gti_ind - 1])) )
 
                     if local_t < 0:
                         logger.error(" Negative local_t, stop\n")
@@ -570,6 +571,30 @@ class light_curve(observation):
 
 def hratio_func(soft_lcname, hard_lcname, hratio_fname, min_sn: float, max_time=1e4, gti_threshold=100, flag_rebin=1, min_bin_size=0,
            ext_t0=-1, max_point_sn=100, single_point_check=False):
+
+    logger.info("Soft LC " + soft_lcname)
+    logger.info("Hard LC " + hard_lcname)
+
+    if hratio_fname is not None:
+        logger.info("Hardness ratio output file " + hratio_fname)
+    else:
+        logger.info("No Hardness ratio file")
+
+    logger.info("Minimun S/N %f" % min_sn)
+    logger.info("Maximum bin length %f" % max_time)
+    logger.info("Threshod to use a GTI gap %f" % gti_threshold)
+    flag_rebin_dict = {
+        1: "soft",
+        2: "Hard",
+        3: "Summed",
+        4: "Hardness ratio"
+    }
+    logger.info("Rebin on %s light curve" % flag_rebin_dict[flag_rebin])
+    logger.info("Minimum bin size %f" % min_bin_size)
+    logger.info("External T0 %f (if <0, first bin)" % ext_t0)
+    logger.info("Check on single point %r" % single_point_check)
+    logger.info("Maximum allowed S/N for one point %f\n\n" % max_point_sn)
+
     soft_lc = light_curve()
     soft_lc.read_from_fits(soft_lcname)
     hard_lc = light_curve()
@@ -618,15 +643,18 @@ def write_qdp(soft_lc, hard_lc, hratio_lc, hratio_fname, ext_t0):
     off_time = 0
     scale_unit = 1
     if soft_lc._times_[0] > 1e8 and ext_t0 < 0:
+        logger.debug("Use first bin as t0 : %f %f " % (soft_lc._times_[0], ext_t0))
         off_time = np.floor(soft_lc._times_[0])
         ff.write("lab x Time since %f\n" % (off_time / scale_unit))
         ff.write("!lab x Time since %s\n" % (off_time))
     elif ext_t0 >= 0:
+        logger.debug("Use ext_t0 : %f " % (ext_t0))
         off_time = np.floor(ext_t0)
         ff.write("lab x Time since %f\n" % (off_time / scale_unit))
         ff.write("!lab x Time since %f\n" % off_time)
     else:
-        ff.write("lab x Time [s]")
+        logger.debug("Does not use a t0 : %f %f " % (soft_lc._times_[0], ext_t0))
+        ff.write("lab x Time [s]\n")
 
     ff.write("lab y2 Soft [cts/s]\n")
     ff.write("lab y3 Hard [cts/s]\n")
